@@ -1,4 +1,5 @@
-from lz4.frame import compress as _compress, decompress as _decompress
+from lz4.frame import compress as _compress
+from lz4.frame import decompress as _decompress
 
 from ..exceptions import CompressorError
 from .base import BaseCompressor
@@ -7,12 +8,12 @@ from .base import BaseCompressor
 class Lz4Compressor(BaseCompressor):
     min_length = 15
 
-    def compress(self, value):
+    def compress(self, value: bytes) -> bytes:
         if len(value) > self.min_length:
             return _compress(value)
         return value
 
-    def decompress(self, value):
+    def decompress(self, value: bytes) -> bytes:
         try:
             return _decompress(value)
         except Exception as e:
