@@ -8,12 +8,12 @@ class LzmaCompressor(BaseCompressor):
     min_length = 100
     preset = 4
 
-    def compress(self, value):
+    def compress(self, value: bytes) -> bytes:
         if len(value) > self.min_length:
             return lzma.compress(value, preset=self.preset)
         return value
 
-    def decompress(self, value):
+    def decompress(self, value: bytes) -> bytes:
         try:
             return lzma.decompress(value)
         except lzma.LZMAError as e:
