@@ -3,10 +3,10 @@ from typing import Iterable
 import pytest
 from django.core.cache import cache as default_cache
 
-from django_redis.cache import RedisCache
+from django_redis.cache import BaseCache
 
 
 @pytest.fixture
-def cache() -> Iterable[RedisCache]:
+def cache() -> Iterable[BaseCache]:
     yield default_cache
     default_cache.clear()
