@@ -23,6 +23,16 @@ CACHES = {
     },
 }
 
-INSTALLED_APPS = ["django.contrib.sessions"]
+# Include `django.contrib.auth` and `django.contrib.contenttypes` for mypy /
+# django-stubs.
+
+# See:
+# - https://github.com/typeddjango/django-stubs/issues/318
+# - https://github.com/typeddjango/django-stubs/issues/534
+INSTALLED_APPS = [
+    "django.contrib.auth",
+    "django.contrib.contenttypes",
+    "django.contrib.sessions",
+]
 
 USE_TZ = False
