@@ -2,21 +2,29 @@ import datetime
 import threading
 import time
 from datetime import timedelta
-from typing import List, Union, cast
+from typing import Iterable, List, Union, cast
 from unittest.mock import patch
 
 import pytest
 from django.core.cache import caches
+from django.test import override_settings
 from pytest_django.fixtures import SettingsWrapper
 from pytest_mock import MockerFixture
 
-import django_redis.cache
 from django_redis.cache import RedisCache
 from django_redis.client import ShardClient, herd
 from django_redis.serializers.json import JSONSerializer
 from django_redis.serializers.msgpack import MSGPackSerializer
 
-herd.CACHE_HERD_TIMEOUT = 2
+
+@pytest.fixture
+def patch_itersize_setting() -> Iterable[None]:
+    # destroy cache to force recreation with overriden settings
+    del caches["default"]
+    with override_settings(DJANGO_REDIS_SCAN_ITERSIZE=30):
+        yield
+    # destroy cache to force recreation with original settings
+    del caches["default"]
 
 
 class TestDjangoRedisCache:
@@ -199,7 +207,12 @@ class TestDjangoRedisCache:
         res = cache.get_many(["a", "b", "c"])
         assert res == {"a": 1, "b": 2, "c": 3}
 
-    def test_set_call_empty_pipeline(self, cache: RedisCache, mocker: MockerFixture):
+    def test_set_call_empty_pipeline(
+        self,
+        cache: RedisCache,
+        mocker: MockerFixture,
+        settings: SettingsWrapper,
+    ):
         if isinstance(cache.client, ShardClient):
             pytest.skip("ShardClient doesn't support get_client")
 
@@ -212,7 +225,7 @@ class TestDjangoRedisCache:
 
         if isinstance(cache.client, herd.HerdClient):
             default_timeout = cache.client._backend.default_timeout
-            herd_timeout = (default_timeout + herd.CACHE_HERD_TIMEOUT) * 1000
+            herd_timeout = (default_timeout + settings.CACHE_HERD_TIMEOUT) * 1000
             herd_pack_value = cache.client._pack(value, default_timeout)
             mocked_set.assert_called_once_with(
                 cache.client.make_key(key, version=None),
@@ -495,11 +508,15 @@ class TestDjangoRedisCache:
 
     @patch("django_redis.cache.RedisCache.client")
     def test_delete_pattern_with_settings_default_scan_count(
-        self, client_mock, cache: RedisCache
+        self,
+        client_mock,
+        patch_itersize_setting,
+        cache: RedisCache,
+        settings: SettingsWrapper,
     ):
         for key in ["foo-aa", "foo-ab", "foo-bb", "foo-bc"]:
             cache.set(key, "foo")
-        expected_count = django_redis.cache.DJANGO_REDIS_SCAN_ITERSIZE
+        expected_count = settings.DJANGO_REDIS_SCAN_ITERSIZE
 
         cache.delete_pattern("*foo-a*")
 
@@ -541,7 +558,6 @@ class TestDjangoRedisCache:
         assert ttl == 0
 
     def test_pttl(self, cache: RedisCache):
-
         # Test pttl
         cache.set("foo", "bar", 10)
         ttl = cache.pttl("foo")
@@ -599,7 +615,6 @@ class TestDjangoRedisCache:
         assert cache.pexpire("not-existent-key", 20500) is False
 
     def test_pexpire_at(self, cache: RedisCache):
-
         # Test settings expiration time 1 hour ahead by datetime.
         cache.set("foo", "bar", timeout=None)
         expiration_time = datetime.datetime.now() + timedelta(hours=1)
@@ -625,7 +640,6 @@ class TestDjangoRedisCache:
         assert cache.pexpire_at("not-existent-key", expiration_time) is False
 
     def test_expire_at(self, cache: RedisCache):
-
         # Test settings expiration time 1 hour ahead by datetime.
         cache.set("foo", "bar", timeout=None)
         expiration_time = datetime.datetime.now() + timedelta(hours=1)
